@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package RDF::aREF;
 #ABSTRACT: Another RDF Encoding Form
-our $VERSION = '0.06'; #VERSION
+our $VERSION = '0.07'; #VERSION
 
 use RDF::aREF::Decoder;
 
@@ -10,6 +10,12 @@ use parent 'Exporter';
 our @EXPORT = qw(decode_aref);
 our @EXPORT_OK = qw(aref_to_trine_statement decode_aref);
 
+sub decode_aref(@) { ## no critic
+    my ($aref, %options) = @_;
+    RDF::aREF::Decoder->new(%options)->decode($aref);
+}
+
+# experimental
 # TODO: test this
 sub aref_to_trine_statement {
     require RDF::Trine::Statement;
@@ -33,11 +39,6 @@ sub aref_to_trine_statement {
     );
 }
 
-sub decode_aref(@) { ## no critic
-    my ($aref, %options) = @_;
-    RDF::aREF::Decoder->new(%options)->decode($aref);
-}
-
 1;
 
 __END__
@@ -52,7 +53,7 @@ RDF::aREF - Another RDF Encoding Form
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -83,14 +84,19 @@ version 0.06
 
 =head1 DESCRIPTION
 
-This module decodes B<another RDF Encoding Form (aREF)> to RDF triples.
+aREF (L<another RDF Encoding Form|http://gbv.github.io/aREF/>) is an encoding
+of RDF graphs in form of arrays, hashes, and Unicode strings. This module 
+implements decoding from aREF data to RDF triples.
 
 =head1 EXPORTED FUNCTIONS
 
 =head2 decode_aref ( $aref, [ %options ] )
 
-Decodes an aREF document given as hash referece. Options are passed to the
-constructor of L<RDF::aREF::Decoder>.
+Decodes an aREF document given as hash referece. This function is a shortcut for
+
+    RDF::aREF::Decoder->new(%options)->decode($aref)
+
+See L<RDF::aREF::Decoder> for possible options.
 
 =head1 SEE ALSO
 
@@ -106,7 +112,7 @@ aREF is being specified at L<http://github.com/gbv/aREF>.
 
 =item
 
-See L<RDF::YAML> for an outdated similar RDF encoding in YAML.
+See L<RDF::YAML> for a similar (outdated) RDF encoding in YAML.
 
 =back
 
